@@ -4,7 +4,7 @@
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
- * the COPYING file, which can be found at the root of the source code       *
+ * the LICENSE file, which can be found at the root of the source code       *
  * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
@@ -477,8 +477,10 @@ test_array_info()
  *-------------------------------------------------------------------------
  */
 extern "C" void
-test_array()
+test_array(void *params)
 {
+    (void)params;
+
     // Output message about test being performed
     MESSAGE(5, ("Testing Array Datatypes\n"));
 
@@ -502,7 +504,11 @@ test_array()
  *-------------------------------------------------------------------------
  */
 extern "C" void
-cleanup_array()
+cleanup_array(void *params)
 {
-    HDremove(FILENAME.c_str());
+    (void)params;
+
+    if (GetTestCleanup()) {
+        HDremove(FILENAME.c_str());
+    }
 } // cleanup_array
