@@ -4,7 +4,7 @@
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
- * the COPYING file, which can be found at the root of the source code       *
+ * the LICENSE file, which can be found at the root of the source code       *
  * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
@@ -16,6 +16,17 @@ import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
 
+import java.lang.foreign.Arena;
+import java.lang.foreign.FunctionDescriptor;
+import java.lang.foreign.Linker;
+import java.lang.foreign.MemoryLayout;
+import java.lang.foreign.MemoryLayout.PathElement;
+import java.lang.foreign.MemorySegment;
+import java.lang.foreign.SequenceLayout;
+import java.lang.foreign.ValueLayout;
+import java.lang.invoke.MethodHandle;
+import java.lang.invoke.VarHandle;
+import java.nio.charset.StandardCharsets;
 import java.util.ArrayList;
 
 import hdf.hdf5lib.H5;
@@ -25,6 +36,7 @@ import hdf.hdf5lib.callbacks.H5L_iterate_t;
 import hdf.hdf5lib.exceptions.HDF5LibraryException;
 import hdf.hdf5lib.structs.H5L_info_t;
 
+import org.hdfgroup.javahdf5.H5L_info2_t;
 import org.junit.After;
 import org.junit.Before;
 import org.junit.Rule;
@@ -261,14 +273,15 @@ public class TestH5Lbasic {
             }
         }
         class H5L_iter_data implements H5L_iterate_opdata_t {
-            public ArrayList<idata> iterdata = new ArrayList<idata>();
+            static public ArrayList<idata> iterdata = new ArrayList<idata>();
+            static void add_iter_data(idata id) { iterdata.add(id); }
         }
         H5L_iterate_opdata_t iter_data = new H5L_iter_data();
         class H5L_iter_callback implements H5L_iterate_t {
-            public int callback(long group, String name, H5L_info_t info, H5L_iterate_opdata_t op_data)
+            public int apply(long group, MemorySegment name, MemorySegment info, MemorySegment op_data)
             {
-                idata id = new idata(name, info.type);
-                ((H5L_iter_data)op_data).iterdata.add(id);
+                idata id = new idata(name.getString(0), H5L_info2_t.type(info));
+                ((H5L_iter_data)iter_data).add_iter_data(id);
                 return 0;
             }
         }
@@ -308,14 +321,15 @@ public class TestH5Lbasic {
             }
         }
         class H5L_iter_data implements H5L_iterate_opdata_t {
-            public ArrayList<idata> iterdata = new ArrayList<idata>();
+            static public ArrayList<idata> iterdata = new ArrayList<idata>();
+            static void add_iter_data(idata id) { iterdata.add(id); }
         }
         H5L_iterate_opdata_t iter_data = new H5L_iter_data();
         class H5L_iter_callback implements H5L_iterate_t {
-            public int callback(long group, String name, H5L_info_t info, H5L_iterate_opdata_t op_data)
+            public int apply(long group, MemorySegment name, MemorySegment info, MemorySegment op_data)
             {
-                idata id = new idata(name, info.type);
-                ((H5L_iter_data)op_data).iterdata.add(id);
+                idata id = new idata(name.getString(0), H5L_info2_t.type(info));
+                ((H5L_iter_data)iter_data).add_iter_data(id);
                 return 0;
             }
         }
@@ -348,14 +362,15 @@ public class TestH5Lbasic {
             }
         }
         class H5L_iter_data implements H5L_iterate_opdata_t {
-            public ArrayList<idata> iterdata = new ArrayList<idata>();
+            static public ArrayList<idata> iterdata = new ArrayList<idata>();
+            static void add_iter_data(idata id) { iterdata.add(id); }
         }
         H5L_iterate_opdata_t iter_data = new H5L_iter_data();
         class H5L_iter_callback implements H5L_iterate_t {
-            public int callback(long group, String name, H5L_info_t info, H5L_iterate_opdata_t op_data)
+            public int apply(long group, MemorySegment name, MemorySegment info, MemorySegment op_data)
             {
-                idata id = new idata(name, info.type);
-                ((H5L_iter_data)op_data).iterdata.add(id);
+                idata id = new idata(name.getString(0), H5L_info2_t.type(info));
+                ((H5L_iter_data)iter_data).add_iter_data(id);
                 return 0;
             }
         }
@@ -395,14 +410,15 @@ public class TestH5Lbasic {
             }
         }
         class H5L_iter_data implements H5L_iterate_opdata_t {
-            public ArrayList<idata> iterdata = new ArrayList<idata>();
+            static public ArrayList<idata> iterdata = new ArrayList<idata>();
+            static void add_iter_data(idata id) { iterdata.add(id); }
         }
         H5L_iterate_opdata_t iter_data = new H5L_iter_data();
         class H5L_iter_callback implements H5L_iterate_t {
-            public int callback(long group, String name, H5L_info_t info, H5L_iterate_opdata_t op_data)
+            public int apply(long group, MemorySegment name, MemorySegment info, MemorySegment op_data)
             {
-                idata id = new idata(name, info.type);
-                ((H5L_iter_data)op_data).iterdata.add(id);
+                idata id = new idata(name.getString(0), H5L_info2_t.type(info));
+                ((H5L_iter_data)iter_data).add_iter_data(id);
                 return 0;
             }
         }
