@@ -4,7 +4,7 @@
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
- * the COPYING file, which can be found at the root of the source code       *
+ * the LICENSE file, which can be found at the root of the source code       *
  * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
@@ -24,12 +24,9 @@
 #include "H5Dpkg.h"      /* Dataset functions                        */
 #include "H5Eprivate.h"  /* Error handling                           */
 #include "H5FLprivate.h" /* Free Lists                               */
-#include "H5Iprivate.h"  /* IDs                                      */
 #include "H5MMprivate.h" /* Memory management                        */
 #include "H5Sprivate.h"  /* Dataspace                                */
 
-#include "H5VLnative_private.h" /* Native VOL connector                     */
-
 /****************/
 /* Local Macros */
 /****************/
@@ -46,7 +43,8 @@
 static herr_t H5D__ioinfo_init(size_t count, H5D_io_op_type_t op_type, H5D_dset_io_info_t *dset_info,
                                H5D_io_info_t *io_info);
 static herr_t H5D__dset_ioinfo_init(H5D_t *dset, H5D_dset_io_info_t *dset_info, H5D_storage_t *store);
-static herr_t H5D__typeinfo_init(H5D_io_info_t *io_info, H5D_dset_io_info_t *dset_info, hid_t mem_type_id);
+static herr_t H5D__typeinfo_init(H5D_io_info_t *io_info, H5D_dset_io_info_t *dset_info,
+                                 const H5T_t *mem_type);
 static herr_t H5D__typeinfo_init_phase2(H5D_io_info_t *io_info);
 static herr_t H5D__typeinfo_init_phase3(H5D_io_info_t *io_info);
 #ifdef H5_HAVE_PARALLEL
@@ -105,7 +103,7 @@ H5D__read(size_t count, H5D_dset_io_info_t *dset_info)
     char   fake_char; /* Temporary variable for NULL buffer pointers */
     herr_t ret_value = SUCCEED; /* Return value	*/
 
-    FUNC_ENTER_NOAPI(FAIL)
+    FUNC_ENTER_PACKAGE
 
 #ifdef H5_HAVE_PARALLEL
     /* Reset the actual io mode properties to the default values in case
@@ -157,7 +155,7 @@ H5D__read(size_t count, H5D_dset_io_info_t *dset_info)
         H5AC_tag(dset_info[i].dset->oloc.addr, &prev_tag);
 
         /* Set up datatype info for operation */
-        if (H5D__typeinfo_init(&io_info, &(dset_info[i]), dset_info[i].mem_type_id) < 0)
+        if (H5D__typeinfo_init(&io_info, &(dset_info[i]), dset_info[i].mem_type) < 0)
             HGOTO_ERROR(H5E_DATASET, H5E_CANTINIT, FAIL, "unable to set up type info");
 
         /* Make certain that the number of elements in each selection is the same, and cache nelmts in
@@ -397,8 +395,12 @@ H5D__read(size_t count, H5D_dset_io_info_t *dset_info)
             H5AC_tag(dset_info[i].dset->oloc.addr, &prev_tag);
 
             /* Invoke correct "high level" I/O routine */
-            if ((*dset_info[i].io_ops.multi_read)(&io_info, &dset_info[i]) < 0)
+            if ((*dset_info[i].io_ops.multi_read)(&io_info, &dset_info[i]) < 0) {
+                /* Reset metadata tagging */
+                H5AC_tag(prev_tag, NULL);
+
                 HGOTO_ERROR(H5E_DATASET, H5E_READERROR, FAIL, "can't read data");
+            }
 
             /* Reset metadata tagging */
             H5AC_tag(prev_tag, NULL);
@@ -528,7 +530,7 @@ H5D__write(size_t count, H5D_dset_io_info_t *dset_info)
     char           fake_char;                 /* Temporary variable for NULL buffer pointers */
     herr_t         ret_value = SUCCEED;       /* Return value	*/
 
-    FUNC_ENTER_NOAPI(FAIL)
+    FUNC_ENTER_PACKAGE
 
 #ifdef H5_HAVE_PARALLEL
     /* Reset the actual io mode properties to the default values in case
@@ -566,6 +568,10 @@ H5D__write(size_t count, H5D_dset_io_info_t *dset_info)
 
         /* All filters in the DCPL must have encoding enabled. */
         if (!dset_info[i].dset->shared->checked_filters) {
+            /* Flush layout to DCPL before readaing */
+            if (H5D_flush_layout_to_dcpl(dset_info[i].dset) < 0)
+                HGOTO_ERROR(H5E_DATASET, H5E_CANTSET, FAIL, "unable to flush layout");
+
             if (H5Z_can_apply(dset_info[i].dset->shared->dcpl_id, dset_info[i].dset->shared->type_id) < 0)
                 HGOTO_ERROR(H5E_PLINE, H5E_CANAPPLY, FAIL, "can't apply filters");
 
@@ -577,7 +583,7 @@ H5D__write(size_t count, H5D_dset_io_info_t *dset_info)
             HGOTO_ERROR(H5E_DATASET, H5E_WRITEERROR, FAIL, "no write intent on file");
 
         /* Set up datatype info for operation */
-        if (H5D__typeinfo_init(&io_info, &(dset_info[i]), dset_info[i].mem_type_id) < 0)
+        if (H5D__typeinfo_init(&io_info, &(dset_info[i]), dset_info[i].mem_type) < 0)
             HGOTO_ERROR(H5E_DATASET, H5E_CANTINIT, FAIL, "unable to set up type info");
 
             /* Various MPI based checks */
@@ -1040,12 +1046,10 @@ H5D__dset_ioinfo_init(H5D_t *dset, H5D_dset_io_info_t *dset_info, H5D_storage_t
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5D__typeinfo_init(H5D_io_info_t *io_info, H5D_dset_io_info_t *dset_info, hid_t mem_type_id)
+H5D__typeinfo_init(H5D_io_info_t *io_info, H5D_dset_io_info_t *dset_info, const H5T_t *mem_type)
 {
     H5D_type_info_t  *type_info;
     const H5D_t      *dset;
-    const H5T_t      *src_type;            /* Source datatype */
-    const H5T_t      *dst_type;            /* Destination datatype */
     H5Z_data_xform_t *data_transform;      /* Data transform info */
     herr_t            ret_value = SUCCEED; /* Return value	*/
 
@@ -1054,6 +1058,7 @@ H5D__typeinfo_init(H5D_io_info_t *io_info, H5D_dset_io_info_t *dset_info, hid_t
     /* Check args */
     assert(io_info);
     assert(dset_info);
+    assert(mem_type);
 
     /* Set convenience pointers */
     type_info = &dset_info->type_info;
@@ -1068,21 +1073,16 @@ H5D__typeinfo_init(H5D_io_info_t *io_info, H5D_dset_io_info_t *dset_info, hid_t
     memset(type_info, 0, sizeof(*type_info));
 
     /* Get the memory & dataset datatypes */
-    if (NULL == (type_info->mem_type = (const H5T_t *)H5I_object_verify(mem_type_id, H5I_DATATYPE)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a datatype");
+    type_info->mem_type  = mem_type;
     type_info->dset_type = dset->shared->type;
 
     if (io_info->op_type == H5D_IO_OP_WRITE) {
-        src_type               = type_info->mem_type;
-        dst_type               = dset->shared->type;
-        type_info->src_type_id = mem_type_id;
-        type_info->dst_type_id = dset->shared->type_id;
+        type_info->src_type = mem_type;
+        type_info->dst_type = dset->shared->type;
     } /* end if */
     else {
-        src_type               = dset->shared->type;
-        dst_type               = type_info->mem_type;
-        type_info->src_type_id = dset->shared->type_id;
-        type_info->dst_type_id = mem_type_id;
+        type_info->src_type = dset->shared->type;
+        type_info->dst_type = mem_type;
     } /* end else */
 
     /* Locate the type conversion function and dataspace conversion
@@ -1092,7 +1092,7 @@ H5D__typeinfo_init(H5D_io_info_t *io_info, H5D_dset_io_info_t *dset_info, hid_t
      * enough value in xfer_parms since turning off datatype conversion also
      * turns off background preservation.
      */
-    if (NULL == (type_info->tpath = H5T_path_find(src_type, dst_type)))
+    if (NULL == (type_info->tpath = H5T_path_find(type_info->src_type, type_info->dst_type)))
         HGOTO_ERROR(H5E_DATASET, H5E_UNSUPPORTED, FAIL, "unable to convert between src and dest datatype");
 
     /* Retrieve info from API context */
@@ -1100,8 +1100,8 @@ H5D__typeinfo_init(H5D_io_info_t *io_info, H5D_dset_io_info_t *dset_info, hid_t
         HGOTO_ERROR(H5E_DATASET, H5E_CANTGET, FAIL, "can't get data transform info");
 
     /* Precompute some useful information */
-    type_info->src_type_size = H5T_get_size(src_type);
-    type_info->dst_type_size = H5T_get_size(dst_type);
+    type_info->src_type_size = H5T_get_size(type_info->src_type);
+    type_info->dst_type_size = H5T_get_size(type_info->dst_type);
     type_info->is_conv_noop  = H5T_path_noop(type_info->tpath);
     type_info->is_xform_noop = H5Z_xform_noop(data_transform);
     if (type_info->is_xform_noop && type_info->is_conv_noop) {
@@ -1193,9 +1193,15 @@ H5D__typeinfo_init_phase2(H5D_io_info_t *io_info)
 
             /* Check for background buffer */
             if (type_info->need_bkg) {
-                /* Add size of this dataset's background buffer to the global background buffer size
-                 */
-                io_info->bkg_buf_size += io_info->dsets_info[i].nelmts * type_info->dst_type_size;
+                hsize_t bkg_buf_hsize;
+
+                /* Add size of this dataset's background buffer to the global background buffer size. Make
+                 * sure to check for overflow and disable selection I/O if it happens. */
+                H5_CHECKED_ASSIGN(bkg_buf_hsize, hsize_t, io_info->bkg_buf_size, size_t);
+                bkg_buf_hsize += io_info->dsets_info[i].nelmts * type_info->dst_type_size;
+                io_info->bkg_buf_size = (size_t)bkg_buf_hsize;
+                if (H5_UNLIKELY((hsize_t)io_info->bkg_buf_size != bkg_buf_hsize))
+                    io_info->tconv_buf_overflow = true;
 
                 /* Check if we need to fill the background buffer with the destination contents */
                 if (type_info->need_bkg == H5T_BKG_YES)
@@ -1208,14 +1214,14 @@ H5D__typeinfo_init_phase2(H5D_io_info_t *io_info)
             HGOTO_ERROR(H5E_DATASET, H5E_CANTGET, FAIL, "can't retrieve max. temp. buf size");
 
         /* Check if the needed type conversion or background buffer size is too big */
-        if (io_info->tconv_buf_size > max_temp_buf) {
+        if (io_info->tconv_buf_size > max_temp_buf || io_info->tconv_buf_overflow) {
             io_info->use_select_io = H5D_SELECTION_IO_MODE_OFF;
             io_info->no_selection_io_cause |= H5D_SEL_IO_TCONV_BUF_TOO_SMALL;
             io_info->tconv_buf_size = 0;
             io_info->bkg_buf_size   = 0;
             io_info->must_fill_bkg  = false;
         }
-        if (io_info->bkg_buf_size > max_temp_buf) {
+        if (io_info->bkg_buf_size > max_temp_buf || io_info->tconv_buf_overflow) {
             io_info->use_select_io = H5D_SELECTION_IO_MODE_OFF;
             io_info->no_selection_io_cause |= H5D_SEL_IO_BKG_BUF_TOO_SMALL;
             io_info->tconv_buf_size = 0;
