@@ -4,7 +4,7 @@
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
- * the COPYING file, which can be found at the root of the source code       *
+ * the LICENSE file, which can be found at the root of the source code       *
  * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
@@ -55,10 +55,9 @@ tst_rev_sort(const void *i1, const void *i2)
 static void
 test_skiplist_init(void)
 {
-    time_t   curr_time; /* Current time, for seeding random number generator */
-    int      new_val;   /* New value to insert */
-    unsigned found;     /* Flag to indicate value was inserted already */
-    size_t   u, v;      /* Local index variables */
+    int      new_val; /* New value to insert */
+    unsigned found;   /* Flag to indicate value was inserted already */
+    size_t   u, v;    /* Local index variables */
 
     /* Allocate arrays */
     rand_num = (int *)malloc(sizeof(int) * NUM_ELEMS);
@@ -69,8 +68,7 @@ test_skiplist_init(void)
     CHECK_PTR(rev_sort_rand_num, "malloc");
 
     /* Initialize random number seed */
-    curr_time = HDtime(NULL);
-    HDsrandom((unsigned)curr_time);
+    srand((unsigned)time(NULL));
 
     /* Create randomized set of numbers */
     for (u = 0; u < NUM_ELEMS; u++) {
@@ -79,7 +77,7 @@ test_skiplist_init(void)
             found = 0;
 
             /* Generate random numbers from -5000 to 5000 */
-            new_val = (int)(HDrandom() % 10001) - 5001;
+            new_val = (int)(rand() % 10001) - 5001;
 
             /* Check if the value is already in the array */
             for (v = 0; v < u; v++)
@@ -531,9 +529,9 @@ test_skiplist_string(void)
         const char *s;
     } string_node;
     string_node  data[10]        = {{10, "10"}, {20, "20"}, {15, "15"}, {5, "05"},  {50, "50"},
-                            {30, "30"}, {31, "31"}, {32, "32"}, {80, "80"}, {90, "90"}};
+                                    {30, "30"}, {31, "31"}, {32, "32"}, {80, "80"}, {90, "90"}};
     string_node  hashed_data[10] = {{5, "05"},  {10, "10"}, {15, "15"}, {20, "20"}, {30, "30"},
-                                   {31, "31"}, {32, "32"}, {50, "50"}, {80, "80"}, {90, "90"}};
+                                    {31, "31"}, {32, "32"}, {50, "50"}, {80, "80"}, {90, "90"}};
     string_node *found_item; /* Item found in skip list */
     herr_t       ret;        /* Generic return value */
 
@@ -755,9 +753,9 @@ test_skiplist_obj(void)
     size_t       num;   /* Number of elements in skip list */
     size_t       u;     /* Local index variable */
     H5_obj_t     data[10]        = {{10, 12}, {20, 12}, {10, 32}, {10, 11}, {50, 1},
-                         {8, 12},  {31, 12}, {20, 11}, {31, 11}, {8, 32}};
+                                    {8, 12},  {31, 12}, {20, 11}, {31, 11}, {8, 32}};
     H5_obj_t     sorted_data[10] = {{8, 12},  {8, 32},  {10, 11}, {10, 12}, {10, 32},
-                                {20, 11}, {20, 12}, {31, 11}, {31, 12}, {50, 1}};
+                                    {20, 11}, {20, 12}, {31, 11}, {31, 12}, {50, 1}};
     H5_obj_t    *found_item; /* Item found in skip list */
     herr_t       ret;        /* Generic return value */
 
@@ -836,9 +834,9 @@ test_skiplist_generic(void)
     size_t       num;   /* Number of elements in skip list */
     size_t       u;     /* Local index variable */
     generic_t    data[10]        = {{10, 1},   {20, 13}, {15, 32}, {5, 2},   {50, 37},
-                          {30, 100}, {31, 38}, {32, 34}, {80, 32}, {90, 0}};
+                                    {30, 100}, {31, 38}, {32, 34}, {80, 32}, {90, 0}};
     generic_t    sorted_data[10] = {{30, 100}, {15, 32}, {31, 38}, {32, 34}, {5, 2},
-                                 {20, 13},  {10, 1},  {50, 37}, {80, 32}, {90, 0}};
+                                    {20, 13},  {10, 1},  {50, 37}, {80, 32}, {90, 0}};
     generic_t   *found_item; /* Item found in skip list */
     herr_t       ret;        /* Generic return value */
 
@@ -1557,7 +1555,7 @@ test_skiplist_term(void)
 **
 ****************************************************************/
 void
-test_skiplist(void)
+test_skiplist(void H5_ATTR_UNUSED *params)
 {
     /* Output message about test being performed */
     MESSAGE(5, ("Testing Skip Lists\n"));
